==> kadu-2.1.tar.bz2: kadu-2.1/plugins/firewall/translations/firewall_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notification syntax</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%u - uin, %m - message</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Search for unknown person in directory and show window with his personal data.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown chats protection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ignore conferences with all persons unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Protect against chats with unknown persons</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Automatic question</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send confirmation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confirmation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Safe sending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable safe sending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You must confirm each message sent to these people</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message was firewalled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Anonymous chat attempt</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save anonymous chat attempt in history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save anonymous chat attempt in log file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log file path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kadu will ask the question typed below, if someone wants talk to you and you do not have him on your list.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Drop chats with unknown person when I am invisible/unavailable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reaction on right answer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Firewall</name>
    <message>
        <source>I want something</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>flooding DoS attack with emoticons!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>flooding DoS attack!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat with anonim silently dropped.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK, now say hello, and introduce yourself ;-)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User wrote right answer!
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to send this message?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yes and allow until chat closed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%u writes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat with invisible anonim ignored.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>      DATA AND TIME      ::   ID      :: MESSAGE
</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FirewallConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Secured&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Move to &apos;All&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Secured</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This message will be send to unknown person.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right answer for question above - you can use regexp.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FirewallNotification</name>
    <message>
        <source>Message was blocked</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%u writes</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/firewall/translations/firewall_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>@default</name>
    <message>
        <source>Firewall</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification syntax</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%u - uin, %m - message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search for unknown person in directory and show window with his personal data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown chats protection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore conferences with all persons unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Protect against chats with unknown persons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Safe sending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable safe sending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must confirm each message sent to these people</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message was firewalled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Anonymous chat attempt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save anonymous chat attempt in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save anonymous chat attempt in log file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log file path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu will ask the question typed below, if someone wants talk to you and you do not have him on your list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drop chats with unknown person when I am invisible/unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reaction on right answer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Firewall</name>
    <message>
        <source>I want something</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>flooding DoS attack with emoticons!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>flooding DoS attack!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat with anonim silently dropped.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK, now say hello, and introduce yourself ;-)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User wrote right answer!
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to send this message?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes and allow until chat closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat with invisible anonim ignored.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>      DATA AND TIME      ::   ID      :: MESSAGE
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FirewallConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Secured&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move to &apos;All&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Secured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message will be send to unknown person.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right answer for question above - you can use regexp.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FirewallNotification</name>
    <message>
        <source>Message was blocked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
